HOST_DICT = {
    "prod": "10.10.1.35",
    "prod_test": "172.23.198.22",
    "test": "172.23.198.14"
}

PASSWD_DICT = {
    "prod": b'zAIRNzFTFBqTT7RgZXqdIw==',
    "prod_test": b"BipPO6894MBVyng+M0h+XogEROrGPvi/whq8BxjURHQ=",
    "test": b'zAIRNzFTFBqTT7RgZXqdIw=='
}


STORE_BATCH_COUNT = 1000